==> hbase-1.7.1-src.tar.gz: hbase-1.7.1/hbase-common/src/test/java/org/apache/hadoop/hbase/util/TestGsonUtil.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.util;

import static org.junit.Assert.assertEquals;

import org.apache.hadoop.hbase.testclassification.MiscTests;
import org.apache.hadoop.hbase.testclassification.SmallTests;
import org.apache.hbase.thirdparty.com.google.gson.Gson;
import org.junit.Test;
import org.junit.experimental.categories.Category;

@Category({ MiscTests.class, SmallTests.class })
public class TestGsonUtil {

  private static final Gson GSON = GsonUtil.createGson().create();
  private static final Gson DHE_GSON = GsonUtil.createGsonWithDisableHtmlEscaping().create();

  @Test
  public void testDisableHtmlEscaping() {
    // enable html escaping, turn '=' into '\u003d'
    assertEquals("\"\\u003d\\u003d\\u003d\"", GSON.toJson("==="));

    // disable html escaping
    assertEquals("\"===\"", DHE_GSON.toJson("==="));
  }
}

==> hbase-2.4.18-src.tar.gz: hbase-2.4.18/hbase-common/src/test/java/org/apache/hadoop/hbase/util/TestGsonUtil.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.util;

import static org.junit.Assert.assertEquals;

import org.apache.hadoop.hbase.HBaseClassTestRule;
import org.apache.hadoop.hbase.testclassification.MiscTests;
import org.apache.hadoop.hbase.testclassification.SmallTests;
import org.junit.ClassRule;
import org.junit.Test;
import org.junit.experimental.categories.Category;

import org.apache.hbase.thirdparty.com.google.gson.Gson;

@Category({ MiscTests.class, SmallTests.class })
public class TestGsonUtil {

  @ClassRule
  public static final HBaseClassTestRule CLASS_RULE =
    HBaseClassTestRule.forClass(TestGsonUtil.class);

  private static final Gson GSON = GsonUtil.createGson().create();
  private static final Gson DHE_GSON = GsonUtil.createGsonWithDisableHtmlEscaping().create();

  @Test
  public void testDisableHtmlEscaping() {
    // enable html escaping, turn '=' into '\u003d'
    assertEquals("\"\\u003d\\u003d\\u003d\"", GSON.toJson("==="));

    // disable html escaping
    assertEquals("\"===\"", DHE_GSON.toJson("==="));
  }
}
